==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSummaryExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryExpressionDescription } from "./WebSummaryExpressionDescription";
/**
 * @hidden
 */
export let WebSummaryExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryExpressionDescriptionMetadata.a == null) {
                WebSummaryExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryExpressionDescriptionMetadata.c(WebSummaryExpressionDescriptionMetadata.a);
            }
            if (a.j(WebSummaryExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSummaryExpressionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("FieldName", "String");
        }
        static d(a) {
            WebSummaryExpressionDescriptionMetadata.b(a);
            a.aa("WebSummaryExpression", () => new WebSummaryExpressionDescription());
            a.z("WebSummaryExpression", WebSummaryExpressionDescriptionMetadata.a);
        }
    }
    WebSummaryExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryExpressionDescriptionMetadata, 'WebSummaryExpressionDescriptionMetadata');
    WebSummaryExpressionDescriptionMetadata.a = null;
    return WebSummaryExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSummaryExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryExpressionDescription } from "./WebSummaryExpressionDescription";
/**
 * @hidden
 */
export let WebSummaryExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryExpressionDescriptionMetadata.a == null) {
                WebSummaryExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryExpressionDescriptionMetadata.c(WebSummaryExpressionDescriptionMetadata.a);
            }
            if (a.k(WebSummaryExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSummaryExpressionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("FieldName", "String");
        }
        static d(a) {
            WebSummaryExpressionDescriptionMetadata.b(a);
            a.ac("WebSummaryExpression", () => new WebSummaryExpressionDescription());
            a.ab("WebSummaryExpression", WebSummaryExpressionDescriptionMetadata.a);
        }
    }
    WebSummaryExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryExpressionDescriptionMetadata, 'WebSummaryExpressionDescriptionMetadata');
    WebSummaryExpressionDescriptionMetadata.a = null;
    return WebSummaryExpressionDescriptionMetadata;
})();
